@@ -3,7 +3,7 @@ use std::str;
 use std::cmp;
 
 use {
-    ErrorPos,
+    TextPos,
     StreamError,
     StrSpan,
     XmlByteExt,
@@ -19,7 +19,7 @@ pub enum Reference<'a> {
     /// An entity reference.
     ///
     /// <https://www.w3.org/TR/xml/#NT-EntityRef>
-    EntityRef(StrSpan<'a>),
+    EntityRef(&'a str),
     /// A character reference.
     ///
     /// <https://www.w3.org/TR/xml/#NT-CharRef>
@@ -268,7 +268,7 @@ impl<'a> Stream<'a> {
         } else if c == b'&' {
             // Check for (#x20 | #x9 | #xD | #xA).
             let mut s = *self;
-            if let Some(v) = s.try_consume_char_reference() {
+            if let Some(Reference::CharRef(v)) = s.try_consume_reference() {
                 if (v as u32) < 255 && (v as u8).is_xml_space() {
                     is_space = true;
                 }
@@ -557,14 +557,15 @@ impl<'a> Stream<'a> {
     /// Consumes an XML character reference if there is one.
     ///
     /// On error will reset the position to the original.
-    pub fn try_consume_char_reference(&mut self) -> Option<char> {
+    pub fn try_consume_reference(&mut self) -> Option<Reference<'a>> {
         let start = self.pos();
 
-        if let Ok(Reference::CharRef(ch)) = self.consume_reference() {
-            Some(ch)
-        } else {
-            self.pos = start;
-            None
+        match self.consume_reference() {
+            Ok(r) => Some(r),
+            Err(_) => {
+                self.pos = start;
+                None
+            }
         }
     }
 
@@ -611,7 +612,7 @@ impl<'a> Stream<'a> {
                 "apos" => Reference::CharRef('\''),
                 "lt"   => Reference::CharRef('<'),
                 "gt"   => Reference::CharRef('>'),
-                _ => Reference::EntityRef(name),
+                _ => Reference::EntityRef(name.to_str()),
             }
         };
 
@@ -634,17 +635,19 @@ impl<'a> Stream<'a> {
     ///
     /// This operation is very expensive. Use only for errors.
     #[inline(never)]
-    pub fn gen_error_pos(&self) -> ErrorPos {
+    pub fn gen_error_pos(&self) -> TextPos {
         let row = self.calc_current_row();
         let col = self.calc_current_col();
-        ErrorPos::new(row, col)
+        TextPos::new(row, col)
     }
 
     /// Calculates an absolute position at `pos`.
     ///
     /// This operation is very expensive. Use only for errors.
     #[inline(never)]
-    pub fn gen_error_pos_from(&self, pos: usize) -> ErrorPos {
+    pub fn gen_error_pos_from(&self, pos: usize) -> TextPos {
+        // TODO: rename
+
         let mut s = *self;
         let old_pos = s.pos;
         s.pos = pos;
@@ -669,9 +672,9 @@ impl<'a> Stream<'a> {
         let bytes = text.as_bytes();
         let end = self.pos + self.span.start();
         let mut col = 1;
-        for n in 0..end {
-            if n > 0 && bytes[n - 1] == b'\n' {
-                col = 2;
+        for c in bytes.iter().take(end) {
+            if *c == b'\n' {
+                col = 1;
             } else {
                 col += 1;
             }
